/*
 * Work under Copyright. Licensed under the EUPL.
 * See the project README.md and LICENSE.txt for more information.
 */

package net.dries007.tfc.objects.te;

import java.util.Random;
import javax.annotation.Nullable;
import javax.annotation.ParametersAreNonnullByDefault;

import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.network.NetworkManager;
import net.minecraft.network.play.server.SPacketUpdateTileEntity;
import net.minecraft.tileentity.TileEntity;
import net.minecraft.util.ResourceLocation;
import net.minecraft.util.math.AxisAlignedBB;
import net.minecraft.util.math.BlockPos;
import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;
import net.minecraftforge.items.ItemStackHandler;

import mcp.MethodsReturnNonnullByDefault;
import net.dries007.tfc.util.Helpers;

import static net.dries007.tfc.api.util.TFCConstants.MOD_ID;

@ParametersAreNonnullByDefault
@MethodsReturnNonnullByDefault
public class TEWorldItem extends TileEntity
{
    public static final ResourceLocation ID = new ResourceLocation(MOD_ID, "world_item");
    public ItemStackHandler inventory = new ItemStackHandler(1);
    private byte rotation;

    public TEWorldItem()
    {
        Random rand = new Random();
        rotation = (byte) rand.nextInt(4);
    }

    public void onBreakBlock(BlockPos pos1)
    {
        Helpers.spawnItemStack(field_145850_b, pos1, inventory.getStackInSlot(0));
    }

    @Override
    public void func_145839_a(NBTTagCompound tag)
    {
        inventory.deserializeNBT(tag.func_74775_l("inventory"));
        rotation = tag.func_74764_b("rotation") ? tag.func_74771_c("rotation") : 0;
        super.func_145839_a(tag);
    }

    @Override
    public NBTTagCompound func_189515_b(NBTTagCompound tag)
    {
        tag.func_74782_a("inventory", inventory.serializeNBT());
        tag.func_74774_a("rotation", rotation);
        return super.func_189515_b(tag);
    }

    @Override
    @SideOnly(Side.CLIENT)
    public double func_145833_n()
    {
        return 1024.0D;
    }

    @Override
    @Nullable
    public SPacketUpdateTileEntity func_189518_D_()
    {
        if (field_145850_b != null)
        {
            return new SPacketUpdateTileEntity(this.func_174877_v(), 0, this.func_189515_b(new NBTTagCompound()));
        }

        return null;
    }

    @Override
    public NBTTagCompound func_189517_E_()
    {
        // The tag from this method is used for the initial chunk packet, and it needs to have the TE position!
        NBTTagCompound nbt = new NBTTagCompound();
        nbt.func_74768_a("x", this.func_174877_v().func_177958_n());
        nbt.func_74768_a("y", this.func_174877_v().func_177956_o());
        nbt.func_74768_a("z", this.func_174877_v().func_177952_p());
        return func_189515_b(nbt);

    }

    @Override
    public void onDataPacket(NetworkManager net, SPacketUpdateTileEntity packet)
    {
        this.handleUpdateTag(packet.func_148857_g());
    }

    @Override
    public void handleUpdateTag(NBTTagCompound tag)
    {
        func_145839_a(tag);
    }

    @Override
    @SideOnly(Side.CLIENT)
    public AxisAlignedBB getRenderBoundingBox()
    {
        return new AxisAlignedBB(func_174877_v(), func_174877_v().func_177963_a(1D, 1D, 1D));
    }

    public byte getRotation()
    {
        return rotation;
    }
}
